@@ -1,4 +1,4 @@
-/* mcparameters.h -- This file is part of Archimedes release 0.1.0.
+/* mcparameters.h -- This file is part of Archimedes release 0.1.2.
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 05 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 10 Sep.2007, Siracusa, J.M.Sellier
+// Last modif. : 13 Sep.2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // Definition of the variables needed for taking into
@@ -36,14 +36,14 @@ void
 MCparameters(int Material)
 {
  real wo,no,dos,aco,oge[7],oga[7];
- real dos1,dos2,am1,am2,eg,cl,deq,dij;
+ real dos1,dos2,am1,am2,cl,deq,dij;
  real hwe,hwij,wij,we,ne,nij;
  real poe,poa,ope,opa,eqe,eqa,qmin,qmax;
  real initialenergy,sei,finalenergy,sef;
  real eps,epf,ep,bimp,cimp,qd;
  real ak,qq,wk;
  int ie,i;
- int z2=4;
+ real z2=4.;
 
  ISEED = 38467.;  //  initial value for random number generator
 
@@ -57,11 +57,6 @@ MCparameters(int Material)
 // Effective mass for the GAMMA and L-Valley, respectively
   am1=MSTAR[Material][1]*M;
   am2=MSTAR[Material][2]*M;
-// Energy minima of bands
-  EC[1]=EMIN[Material][1];
-  EC[2]=EMIN[Material][2];
-// Energy gap
-  eg=EG[Material];
   eps=EPSR[Material];
   epf=EPF[Material]*EPS0;
   ep=1./(1./epf-1./eps);
@@ -127,7 +122,7 @@ MCparameters(int Material)
     SWK[Material][1][2][ie]=SWK[Material][1][1][ie]
                  +poa*SMH[Material][1]*sei/initialenergy/Q*log(qmax/qmin);
 // Emission
-    finalenergy=initialenergy-hwij+EC[1]-EC[2];
+    finalenergy=initialenergy-hwij+EMIN[Material][1]-EMIN[Material][2];
     if(finalenergy>0.){
      sef=sqrt(finalenergy*(1.+alphaK[Material][2]*finalenergy));
      SWK[Material][1][3][ie]=SWK[Material][1][2][ie]
@@ -135,7 +130,7 @@ MCparameters(int Material)
     }
     else SWK[Material][1][3][ie]=SWK[Material][1][2][ie];
 // Absorption
-    finalenergy=initialenergy+hwij+EC[1]-EC[2];
+    finalenergy=initialenergy+hwij+EMIN[Material][1]-EMIN[Material][2];
     if(finalenergy>0.){
      sef=sqrt(finalenergy*(1.+alphaK[Material][2]*finalenergy));
      SWK[Material][1][4][ie]=SWK[Material][1][3][ie]
@@ -191,19 +186,19 @@ MCparameters(int Material)
                  +(z2-1.)*eqa*sef*dos2*(1.+2.*alphaK[Material][2]*finalenergy);
 
 // Emission
-    finalenergy=initialenergy-hwij+EC[2]-EC[1];
+    finalenergy=initialenergy-hwij+EMIN[Material][2]-EMIN[Material][1];
     if(finalenergy>0.){
-     sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
+     sef=sqrt(finalenergy*(1.+alphaK[Material][2]*finalenergy));
      SWK[Material][2][5][ie]=SWK[Material][2][4][ie]
-                            +ope*sef*dos1*(1.+2.*alphaK[Material][1]*finalenergy);
+                            +ope*sef*dos1*(1.+2.*alphaK[Material][2]*finalenergy);
     }
     else SWK[Material][2][5][ie]=SWK[Material][2][4][ie];
 // Absorption
-    finalenergy=initialenergy+hwij+EC[2]-EC[1];
+    finalenergy=initialenergy+hwij+EMIN[Material][2]-EMIN[Material][1];
     if(finalenergy>0.){
-     sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
+     sef=sqrt(finalenergy*(1.+alphaK[Material][2]*finalenergy));
      SWK[Material][2][6][ie]=SWK[Material][2][5][ie]
-                            +opa*sef*dos1*(1.+2.*alphaK[Material][1]*finalenergy);
+                            +opa*sef*dos1*(1.+2.*alphaK[Material][2]*finalenergy);
     }
     else SWK[Material][2][6][ie]=SWK[Material][2][5][ie];
 // Acoustic phonon
